@@ -36,6 +36,7 @@ const Zpj = imports.gi.Zpj;
 const _ = imports.gettext.gettext;
 
 const Lang = imports.lang;
+const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
 const Application = imports.application;
@@ -413,6 +414,20 @@ const DocCommon = new Lang.Class({
 
     load: function(passwd, cancellable, callback) {
         Utils.debug('Loading ' + this.__name__ + ' ' + this.id);
+
+        if (this.collection) {
+            Mainloop.idle_add(Lang.bind(this,
+                function() {
+                    let error = new GLib.Error(Gio.IOErrorEnum,
+                                               Gio.IOErrorEnum.NOT_SUPPORTED,
+                                               "Collections can't be loaded");
+                    callback(this, null, error);
+                    return GLib.SOURCE_REMOVE;
+                }));
+
+            return;
+        }
+
         this.download(true, cancellable, Lang.bind(this,
             function(fromCache, error) {
                 if (error) {
@@ -459,6 +474,9 @@ const DocCommon = new Lang.Class({
     },
 
     canPrint: function(docModel) {
+        if (this.collection)
+            return false;
+
         if (!docModel)
             return false;
 
@@ -757,6 +775,11 @@ const DocCommon = new Lang.Class({
 
                 let printOp = EvView.PrintOperation.new(docModel.get_document());
 
+                printOp.connect('begin-print', Lang.bind(this,
+                    function() {
+                        this.emit('begin-print');
+                    }));
+
                 printOp.connect('done', Lang.bind(this,
                     function(op, res) {
                         if (res == Gtk.PrintOperationResult.ERROR) {
